==> flutter_lingman-0.0.24.tar.gz: lib/request/demon_http.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_lingman/idemon_config.dart';
import 'package:flutter_lingman/request/policy_model.dart';
import 'package:flutter_lingman/request/request_interceptor.dart'; 
import 'package:flutter_svprogresshud/flutter_svprogresshud.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart' hide Response,MultipartFile,FormData;
import 'package:uuid/uuid.dart';   
 
 

class DemonHttp {
  static final DemonHttp _instance = DemonHttp._internal();
  factory DemonHttp() => _instance;

  static late final Dio dio;

  List<CancelToken?> pendingRequest = [];

  DemonHttp._internal() {
    BaseOptions options = BaseOptions(); 

    dio = Dio(options);
   // dio.options.baseUrl = instance.getApiRoot();
    // dio.options.connectTimeout = App.connectTimeout;
    // dio.options.receiveTimeout = App.receiveTimeout;
    // 添加request拦截器
    dio.interceptors.add(RequestInterceptor());
  }
  Future request(String path,
      {String method = "GET",
      Map<String, dynamic>? params,
      data,
      Options? options,
      CancelToken? cancelToken,
      bool refresh = false,
      bool noCache = true,
      String? cacheKey,
      bool needResponse = true,
      bool cacheDisk = false,
      bool isLoading = false}) async {
    if (isLoading) { 
      SVProgressHUD.show();
    }

    Options requestOptions = options ?? Options();
    requestOptions = requestOptions.copyWith(
      method: method,
      extra: {
        "refresh": refresh,
        "noCache": noCache,
        "cacheKey": cacheKey,
        "cacheDisk": cacheDisk,
      },
    );

    Response response;
    CancelToken dioCancelToken = createDioCancelToken(cancelToken);

    if(!path.startsWith("http")) {
      var instance = Get.find<IDemonConfig>();
      if(path.startsWith("/")) { 
        path =  instance.getApiRoot() + path;
      } else {
        path = instance.getApiRoot() + "/" + path;
      }
    }  
    response = await dio
        .request(
      path,
      data: data,
      queryParameters: params,
      options: requestOptions,
      cancelToken: dioCancelToken,
    )
        .whenComplete(() {
      if (isLoading) {
        SVProgressHUD.dismiss();
      }
    });
    pendingRequest.remove(dioCancelToken);

    if(!needResponse) {
      return "";
    }



    ApiResponse result;

    if (response.data != null) {
      result = ApiResponse.fromJson(response.data);
    } else {
      return response.data;
    }

    if (result.code == 1) {
      return result.data;
    }
    if (result.code == 401) { 
      final instance = Get.find<IDemonConfig>();
      instance.makeLogout();
    }
    if (result.code != null) {
      Fluttertoast.showToast(
          msg: result.message ?? "服务器繁忙",
          toastLength: Toast.LENGTH_SHORT,
          gravity: ToastGravity.BOTTOM,
          timeInSecForIosWeb: 1,
          backgroundColor: const Color(0xff000000),
          textColor: Colors.white,
          fontSize: 16.0);

      return Future.error(() {});
    }

    return response.data;
  }

    // 获取oss上传
  static Future<String> uploadOss(File file,{ String policyApi = "/public/oss/policy"  }) async {
    var resp = PolicyModel.fromJson(await DemonHttp().get(policyApi));
    String fileName = resp.dir! +
        const Uuid().v1() +
        (file.path.split('.').last.isEmpty
            ? ""
            : "." + (file.path.split('.').last));
    FormData formData = FormData.fromMap({
      "file": await MultipartFile.fromFile(file.path, filename: fileName),
      "key": fileName,
      "policy": resp.policy,
      "OSSAccessKeyId": resp.accessid,
      "success_action_status": 200,
      "signature": resp.signature
    });
    SVProgressHUD.show();
    await Dio().post(resp.host!, data: formData).whenComplete(() {
      SVProgressHUD.dismiss();
    });
    String fullfilename;
    if (resp.host!.endsWith("/")) {
      fullfilename = resp.host! + fileName;
    } else {
      fullfilename = resp.host! + "/" + fileName;
    }
    return fullfilename;
  }


  Future get(
    String path, {
    Map<String, dynamic>? params,
    bool isLoading = false,
    bool needResponse = true
  }) async {
    return request(path, params: params, isLoading: isLoading, needResponse: needResponse);
  }

  Future post(String path,
      {Map<String, dynamic>? params, data, bool isLoading = false, bool needResponse = true}) async {
    return request(path,
        method: "POST", params: params, data: data, isLoading: isLoading, needResponse: needResponse);
  }

  // 获取cancelToken , 根据传入的参数查看使用者是否有动态传入cancel，没有就生成一个
  CancelToken createDioCancelToken(CancelToken? cancelToken) {
    CancelToken token = cancelToken ?? CancelToken();
    pendingRequest.add(token);
    return token;
  }

  _convertRequestData(data) {
    if (data != null) {
      data = jsonDecode(jsonEncode(data));
    }
    return data;
  }
}

class ApiResponse {
  int? code;
  dynamic data;
  String? message;

  ApiResponse({this.code, this.data, this.message});

  ApiResponse.fromJson(Map<String, dynamic> json) {
    code = json['code'];
    data = json['data'];
    message = json['message'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['code'] = code;
    data['data'] = this.data;
    data['message'] = message;
    return data;
  }
}

==> flutter_lingman-0.0.25.tar.gz: lib/request/demon_http.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_lingman/idemon_config.dart';
import 'package:flutter_lingman/request/policy_model.dart';
import 'package:flutter_lingman/request/request_interceptor.dart'; 
import 'package:flutter_svprogresshud/flutter_svprogresshud.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart' hide Response,MultipartFile,FormData;
import 'package:uuid/uuid.dart';   
 
 

class DemonHttp {
  static final DemonHttp _instance = DemonHttp._internal();
  factory DemonHttp() => _instance;

  static late final Dio dio;

  List<CancelToken?> pendingRequest = [];

  DemonHttp._internal() {
    BaseOptions options = BaseOptions(); 

    dio = Dio(options);
   // dio.options.baseUrl = instance.getApiRoot();
    // dio.options.connectTimeout = App.connectTimeout;
    // dio.options.receiveTimeout = App.receiveTimeout;
    // 添加request拦截器
    dio.interceptors.add(RequestInterceptor());
  }
  Future request(String path,
      {String method = "GET",
      Map<String, dynamic>? params,
      data,
      Options? options,
      CancelToken? cancelToken,
      bool refresh = false,
      bool noCache = true,
      String? cacheKey,
      bool needResponse = true,
      bool cacheDisk = false,
      bool isLoading = false,
      bool isCustomReponse = false
      }) async {
    if (isLoading) { 
      SVProgressHUD.show();
    }

    Options requestOptions = options ?? Options();
    requestOptions = requestOptions.copyWith(
      method: method,
      extra: {
        "refresh": refresh,
        "noCache": noCache,
        "cacheKey": cacheKey,
        "cacheDisk": cacheDisk,
      },
    );

    Response response;
    CancelToken dioCancelToken = createDioCancelToken(cancelToken);

    if(!path.startsWith("http")) {
      var instance = Get.find<IDemonConfig>();
      if(path.startsWith("/")) { 
        path =  instance.getApiRoot() + path;
      } else {
        path = instance.getApiRoot() + "/" + path;
      }
    }  
    response = await dio
        .request(
      path,
      data: data,
      queryParameters: params,
      options: requestOptions,
      cancelToken: dioCancelToken,
    )
        .whenComplete(() {
      if (isLoading) {
        SVProgressHUD.dismiss();
      }
    });
    pendingRequest.remove(dioCancelToken);

    if(!needResponse) {
      return "";
    }



    ApiResponse result;

    if (response.data != null && !isCustomReponse ) {
      result = ApiResponse.fromJson(response.data);
    } else {
      return response.data;
    }

    if (result.code == 1) {
      return result.data;
    }
    if (result.code == 401) { 
      final instance = Get.find<IDemonConfig>();
      instance.makeLogout();
    }
    if (result.code != null) {
      Fluttertoast.showToast(
          msg: result.message ?? "服务器繁忙",
          toastLength: Toast.LENGTH_SHORT,
          gravity: ToastGravity.BOTTOM,
          timeInSecForIosWeb: 1,
          backgroundColor: const Color(0xff000000),
          textColor: Colors.white,
          fontSize: 16.0);

      return Future.error(() {});
    }

    return response.data;
  }

    // 获取oss上传
  static Future<String> uploadOss(File file,{ String policyApi = "/public/oss/policy"  }) async {
    var resp = PolicyModel.fromJson(await DemonHttp().get(policyApi));
    String fileName = resp.dir! +
        const Uuid().v1() +
        (file.path.split('.').last.isEmpty
            ? ""
            : "." + (file.path.split('.').last));
    FormData formData = FormData.fromMap({
      "file": await MultipartFile.fromFile(file.path, filename: fileName),
      "key": fileName,
      "policy": resp.policy,
      "OSSAccessKeyId": resp.accessid,
      "success_action_status": 200,
      "signature": resp.signature
    });
    SVProgressHUD.show();
    await Dio().post(resp.host!, data: formData).whenComplete(() {
      SVProgressHUD.dismiss();
    });
    String fullfilename;
    if (resp.host!.endsWith("/")) {
      fullfilename = resp.host! + fileName;
    } else {
      fullfilename = resp.host! + "/" + fileName;
    }
    return fullfilename;
  }


  Future get(
    String path, {
    Map<String, dynamic>? params,
    bool isLoading = false,
    bool needResponse = true,
    bool isCustomReponse = false
  }) async {
    return request(path, params: params, isLoading: isLoading, needResponse: needResponse, isCustomReponse: isCustomReponse);
  }

  Future post(String path,
      {Map<String, dynamic>? params, data, bool isLoading = false, bool needResponse = true, bool isCustomReponse = false}) async {
    return request(path,
        method: "POST", params: params, data: data, isLoading: isLoading, needResponse: needResponse,isCustomReponse: isCustomReponse);
  }

  // 获取cancelToken , 根据传入的参数查看使用者是否有动态传入cancel，没有就生成一个
  CancelToken createDioCancelToken(CancelToken? cancelToken) {
    CancelToken token = cancelToken ?? CancelToken();
    pendingRequest.add(token);
    return token;
  }

  _convertRequestData(data) {
    if (data != null) {
      data = jsonDecode(jsonEncode(data));
    }
    return data;
  }
}

class ApiResponse {
  int? code;
  dynamic data;
  String? message;

  ApiResponse({this.code, this.data, this.message});

  ApiResponse.fromJson(Map<String, dynamic> json) {
    code = json['code'];
    data = json['data'];
    message = json['message'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['code'] = code;
    data['data'] = this.data;
    data['message'] = message;
    return data;
  }
}
